@@ -34,10 +34,15 @@ package App::Dochazka::Common::Model::Tempintvls;
 
 use 5.012;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 
 use App::Dochazka::Common::Model;
-use constant ATTRS => qw( tiid intvl );
+use constant ATTRS => qw( 
+    tiid
+    tsrange
+    long_desc
+    remark
+);
 
 BEGIN {
     App::Dochazka::Common::Model::boilerplate( __PACKAGE__, ATTRS );
